==> haskell-primitive-addr-0.1.0.2-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-addr
version:              0.1.0.2
visibility:           public
id:                   primitive-addr-0.1.0.2-GswvRfzJ4CUL3DUCfv3Itb
key:                  primitive-addr-0.1.0.2-GswvRfzJ4CUL3DUCfv3Itb
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  8bdfe229cc123d4f808e6cfb414c2492
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-addr-0.1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-addr-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.2-GswvRfzJ4CUL3DUCfv3Itb
depends:
    base-4.16.4.0 primitive-0.7.4.0-1hjisjTIkm1Ju7TlHVggBl

haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-addr-0.1.0.2-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-addr
version:              0.1.0.2
visibility:           public
id:                   primitive-addr-0.1.0.2-4zrLtimEX6N5AuQB5ZjK6j
key:                  primitive-addr-0.1.0.2-4zrLtimEX6N5AuQB5ZjK6j
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  8b647eb3e2302fe37110db6186a978cb
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-addr-0.1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-addr-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.2-4zrLtimEX6N5AuQB5ZjK6j
depends:
    base-4.16.4.0 primitive-0.7.4.0-I9XTAmFqErC1hXdXvvNzkS

haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
